#ifndef NT2_INCLUDE_CONSTANTS_LOG10_PI_HPP_INCLUDED
#define NT2_INCLUDE_CONSTANTS_LOG10_PI_HPP_INCLUDED

#include <nt2/constant/include/constants/log10_pi.hpp>

#endif
